@@ -34,6 +34,10 @@ function(x)
                           dimnames = dimnames(x))
 }
 
+as.simple_triplet_matrix.default <-
+function(x)
+    as.simple_triplet_matrix(as.matrix(x))
+
 as.simple_triplet_matrix.dgTMatrix <-
 function(x)
 {
@@ -171,8 +175,13 @@ function(e1, e2)
             cnms <- colnames(e2)
         if(is.null(rnms) && is.null(cnms))
             NULL
-        else
-            list(rnms, cnms)
+        else {
+            out <- list(rnms, cnms)
+            if(is.null(nms <- names(dimnames(e1))))
+                nms <- names(dimnames(e2))
+            names(out) <- nms
+            out
+        }
     }
 
     ## Obviously, the following could be generalized ...
@@ -301,6 +310,20 @@ function(e1, e2)
     .reduce(e1)
 }
 
+Summary.simple_triplet_matrix <-
+function(..., na.rm = FALSE)
+{
+    v <- unlist(lapply(list(...),
+                       function(e) {
+                           v <- as.simple_triplet_matrix(e)$v
+                           if(length(v) < prod(dim(e)))
+                               v <- c(v, vector(typeof(v), 1L))
+                           v
+                       }),
+                recursive = FALSE)
+    do.call(.Generic, list(v, na.rm = na.rm))
+}
+
 dim.simple_triplet_matrix <-
 function(x)
     c(x$nrow, x$ncol)
@@ -326,6 +349,7 @@ function(x, value)
         else {
             dnx <- vector("list", 2L)
             dnx[!ind] <- lapply(value[!ind], as.character)
+            names(dnx) <- names(value)
         }
     }
     if(is.null(value))
@@ -475,7 +499,7 @@ function(x, i, j, drop = FALSE)
         }
 
         if(!is.null(dnx <- x$dimnames))
-            dnx <- list(dnx[[1L]][i], dnx[[2L]][j])
+            dnx[] <- list(dnx[[1L]][i], dnx[[2L]][j])
 
         i <- if(missing(i)) x$i[pos] else pi[x$i[pos]]
         j <- if(missing(j)) x$j[pos] else pj[x$j[pos]]
@@ -601,6 +625,12 @@ function(x, ...)
     invisible(x)
 }
 
+mean.simple_triplet_matrix <-
+function(x, ...)
+{
+    sum(x$v) / prod(dim(x))
+}
+
 ## Utilities for creating special simple triplet matrices:
 
 simple_triplet_zero_matrix <-
